@@ -6,10 +6,9 @@ import Test.QuickCheck.Instances
 import qualified Data.Scientific as Scientific
 import qualified Data.UUID as UUID
 import qualified Data.Vector as Vector
-import qualified PostgreSQL.Binary.Data as Data
-import qualified PostgreSQL.Binary.Encoder as Encoder
-import qualified PostgreSQL.Binary.Decoder as Decoder
-import qualified Main.TextEncoder  as TextEncoder 
+import qualified PostgreSQL.Binary.Decoding as A
+import qualified PostgreSQL.Binary.Encoding as B
+import qualified Main.TextEncoder as C 
 import qualified Main.PTI as PTI
 import qualified Main.DB as DB
 import qualified Main.IO as IO
@@ -17,14 +16,14 @@ import qualified Database.PostgreSQL.LibPQ as LibPQ
 
 
 roundtrip :: (Show a, Eq a) => 
-  LibPQ.Oid -> (Bool -> Encoder.Encoder a) -> (Bool -> Decoder.Decoder a) -> a -> Property
+  LibPQ.Oid -> (Bool -> (a -> B.Encoding)) -> (Bool -> A.Value a) -> a -> Property
 roundtrip oid encoder decoder value =
   Right value === unsafePerformIO (IO.roundtrip oid encoder decoder value)
 
-stdRoundtrip :: (Show a, Eq a) => LibPQ.Oid -> Encoder.Encoder a -> Decoder.Decoder a -> a -> Property
+stdRoundtrip :: (Show a, Eq a) => LibPQ.Oid -> (a -> B.Encoding) -> A.Value a -> a -> Property
 stdRoundtrip oid encoder decoder value =
   roundtrip oid (const encoder) (const decoder) value
 
-textRoundtrip :: (Show a, Eq a) => LibPQ.Oid -> TextEncoder.Encoder a -> (Bool -> Decoder.Decoder a) -> a -> Property
+textRoundtrip :: (Show a, Eq a) => LibPQ.Oid -> C.Encoder a -> (Bool -> A.Value a) -> a -> Property
 textRoundtrip oid encoder decoder value =
   Right value === unsafePerformIO (IO.textRoundtrip oid encoder decoder value)
